package com.bril.webfile;

import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v7.app.AppCompatActivity;
import android.view.View;
import android.view.Window;
import android.widget.AdapterView;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.Toast;

import com.bril.webfile.adapter.FileAdapter;
import com.bril.webfile.net.client.FileClient;
import com.bril.webfile.response.ChildrenBeans;
import com.bril.webfile.response.FileResponse;
import com.bril.webfile.response.NextCloudResponse;
import com.bril.webfile.treeview.adapter.SimpleTreeListViewAdapter;
import com.bril.webfile.treeview.adapter.TreeViewAdapter;
import com.bril.webfile.treeview.node.Node;

import java.util.ArrayList;
import java.util.List;

import io.reactivex.android.schedulers.AndroidSchedulers;
import io.reactivex.functions.Consumer;
import io.reactivex.schedulers.Schedulers;
import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

/**
 * Created by Xinghx on 2018/6/14
 */

public class FileActivity extends AppCompatActivity implements AdapterView.OnItemClickListener {
    private static final String TAG = "FileActivity";
    private List<FileResponse> fileBean;


    private LinearLayout file_img_backs;
    private ListView fileLv;
    private FileAdapter fileAdapter;
    private FileClient fileClient = new FileClient();
    private NextCloudResponse cloudResponse;
    List<ChildrenBeans> childrenBeansList = new ArrayList<>();

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        requestWindowFeature(Window.FEATURE_NO_TITLE);
        setContentView(R.layout.activity_file_layout);
        fileLv = (ListView) findViewById(R.id.file_lv);
        file_img_backs = (LinearLayout) findViewById(R.id.file_img_backs);

        file_img_backs.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                finish();
            }
        });
        launcherMethod();

    }

    private void launcherMethod() {
        String userId = getIntent().getStringExtra("userId");
        String moduleName = getIntent().getStringExtra("moduleName");

        String realType = "";
        switch (moduleName) {
            case "myselfNetDisk":
                realType = "1";
                chooseNextCloudModule(userId, realType);
                break;
            case "shareFolder":
                realType = "2";
                chooseNextCloudModule(userId,realType);
                break;
            case "documentManager":
                realType = "3";
                chooseNextCloudModule(userId,realType);
                break;
            default:
                chooseSwaggerModule(userId, moduleName);
                break;
        }
    }

    private void chooseNextCloudModule(String userId, String moduleName) {
        fileClient.nextCloud(userId, moduleName).enqueue(new Callback<NextCloudResponse>() {
            @Override
            public void onResponse(Call<NextCloudResponse> call, Response<NextCloudResponse> response) {
                try {
                    cloudResponse = response.body();

                    List<NextCloudResponse.ListBean> list = response.body().getList();
                    for (NextCloudResponse.ListBean listBean : list) {
                        ChildrenBeans childrenBeans = new ChildrenBeans();
                        String type = listBean.getType();
                        String name = listBean.getName();
                        childrenBeans.setName(name);
                        childrenBeans.setType(type);
                        childrenBeansList.add(childrenBeans);
                        addData(listBean.getChildren());
                    }

                    SimpleTreeListViewAdapter simpleTreeListViewAdapter
                            = new SimpleTreeListViewAdapter(fileLv, FileActivity.this, childrenBeansList, 0);
                    fileLv.setAdapter(simpleTreeListViewAdapter);
                    simpleTreeListViewAdapter.setOnNodeClickListener(new TreeViewAdapter.OnTreeNodeClickListener() {
                        @Override
                        public void onClick(Node node, int position) {
                            if (node.isFile()) {
                                Toast.makeText(FileActivity.this, node.getName(), Toast.LENGTH_SHORT).show();
                                Intent intent = new Intent();
                                intent.putExtra("absolutePath", cloudResponse.getAbsolutePath());
                                intent.putExtra("filePaths", node.getName());
                                setResult(0x013, intent);
                                finish();
                            }
                        }
                    });
                } catch (IllegalAccessException e) {
                    e.printStackTrace();
                }

            }

            @Override
            public void onFailure(Call<NextCloudResponse> call, Throwable t) {
                t.printStackTrace();
            }
        });

    }

    private void chooseSwaggerModule(String userId, String moduleName) {

        fileClient.fileList(userId, moduleName)
                .observeOn(AndroidSchedulers.mainThread())
                .subscribeOn(Schedulers.io())
                .subscribe(new Consumer<List<FileResponse>>() {
                    @Override
                    public void accept(List<FileResponse> fileResponse) throws Exception {
                        FileActivity.this.fileBean = fileResponse;
                        fileAdapter = new FileAdapter(fileResponse);
                        fileLv.setAdapter(fileAdapter);
                        fileLv.setOnItemClickListener(FileActivity.this);
                    }
                }, new Consumer<Throwable>() {
                    @Override
                    public void accept(Throwable throwable) throws Exception {
                        throwable.printStackTrace();
                    }
                });
    }

    private void addData(List<NextCloudResponse.ListBean.ChildrenBean> mList) {

        for (NextCloudResponse.ListBean.ChildrenBean childrenBean : mList) {
            if (childrenBean == null) return;
            ChildrenBeans childrenBeans = new ChildrenBeans();
            String name = childrenBean.getName();
            String type = childrenBean.getType();
            childrenBeans.setName(name);
            childrenBeans.setType(type);
            childrenBeansList.add(childrenBeans);
            if (childrenBean.getChildrenBeen() != null) {
                addData(childrenBean.getChildrenBeen());
            }
        }
    }


    @Override
    public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
        FileResponse fileResponse = fileBean.get(position);
        String fileId = fileResponse.getId();
        String file_name = fileResponse.getFile_name();
        String file_path = fileResponse.getFile_path();

        Intent intent = new Intent();
        intent.putExtra("fileId", fileId);
        intent.putExtra("fileName", file_name);
        intent.putExtra("filePath", file_path);
        setResult(0x012, intent);

        finish();
    }
}
